# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .entity_status import EntityStatus


class FolderEntityPromptSandboxData(UniversalBaseModel):
    id: str
    label: str
    created: dt.datetime
    modified: dt.datetime
    status: EntityStatus
    description: typing.Optional[str] = None
    last_deployed_on: typing.Optional[dt.datetime] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
